@@ -2,7 +2,15 @@
 # encoding: utf-8
 # Author: sorin sbarnea
 # License: public domain
-import logging, sys, subprocess, types, time, os, codecs, unittest
+import codecs
+import functools
+import logging
+import os
+import sys
+import subprocess
+import types
+import time
+import unittest
 
 if sys.version_info[0] == 3:
     string_types = str,
@@ -123,8 +131,7 @@ def system2(cmd, cwd=None, logger=_sentinel, stdout=_sentinel, log_command=_sent
     if log_command :
         if timing:
             def secondsToStr(t):
-                from functools import reduce
-                return "%02d:%02d:%02d" % reduce(lambda ll,b : divmod(ll[0],b) + ll[1:], [(t*1000,),1000,60,60])[:3]
+                return "%02d:%02d:%02d" % functools.reduce(lambda ll,b : divmod(ll[0],b) + ll[1:], [(t*1000,),1000,60,60])[:3]
             mylogger("Returned: %d (execution time %s)\n" % (returncode, secondsToStr(time.clock()-t)))
         else:
             mylogger("Returned: %d\n" % returncode)
